@@ -301,6 +301,14 @@ var xmlScenarios = []formatScenario{
 		expected:     expectedXmlProcInstAndHeadComment,
 		scenarioType: "encode",
 	},
+	{
+		description:  "Scalar roundtrip",
+		skipDoc:      true,
+		input:        "<mike>cat</mike>",
+		expression:   ".mike",
+		expected:     "cat",
+		scenarioType: "roundtrip",
+	},
 	{
 		description:  "ProcInst with head comment round trip",
 		skipDoc:      true,
